@@ -1,13 +1,15 @@
-use crate::{
-    checks::{calculate_fee, check_account_for_balance_with_commitment},
-    cli::CliError,
-};
-use clap::ArgMatches;
-use solana_clap_utils::{input_parsers::lamports_of_sol, offline::SIGN_ONLY_ARG};
-use solana_client::rpc_client::RpcClient;
-use solana_sdk::{
-    commitment_config::CommitmentConfig, fee_calculator::FeeCalculator, message::Message,
-    native_token::lamports_to_sol, pubkey::Pubkey,
+use {
+    crate::{
+        checks::{calculate_fee, check_account_for_balance_with_commitment},
+        cli::CliError,
+    },
+    clap::ArgMatches,
+    solana_clap_utils::{input_parsers::lamports_of_sol, offline::SIGN_ONLY_ARG},
+    solana_client::rpc_client::RpcClient,
+    solana_sdk::{
+        commitment_config::CommitmentConfig, fee_calculator::FeeCalculator, message::Message,
+        native_token::lamports_to_sol, pubkey::Pubkey,
+    },
 };
 
 #[derive(Debug, PartialEq, Clone, Copy)]
